# Config Models

> Global < **Model** < Model Method
Model
These values are defined as Meta class attributes in your SQLAlchemy models.
- They should always be lowercase
- They should always omit any `API_` prefix.
Values defined here apply per model and can only be overridden by Model Method configuration values.
Overrides Global

## Sections

- [Example](example.md)
